/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef feluh
#define feluh

#include <QtGui/QGraphicsView>
#include  <QGraphicsRectItem>
#include   <QVector>
#include    <QMap>
#include     <QList>
#include      "con.h"
#include       <QAction> 
#include        <QRubberBand>

class QMenu;
class izlt;
class jelzpn;
class rslt;
class mgzerz;
class felu : public QGraphicsView
<%
	Q_OBJECT
	public:
		felu(QWidget *megkap, jelzpn* nybnvn);
		void ceco();

		QMap<int, rslt*> kket;

		enum kivitl
		<%
			mgmozt = 0,
			meghat = 1,
			tljsn = 2,
			tiszta = 3,
			ugyex = 4,
		%>;

		void kesztm(kivitl tqrost);

		QMenu* elodez;
		QMenu* korrkt;
		QMenu* jo;

		kivitl fortum;

		void keyPressEvent(QKeyEvent *kelt);
		void keyReleaseEvent(QKeyEvent *kelt);
		void focusOutEvent(QFocusEvent *mgmnkl);
		void wheelEvent(QWheelEvent *kelt);
		void mouseDoubleClickEvent(QMouseEvent *mgmnkl);
		void mousePressEvent(QMouseEvent *mgmnkl);
		void mouseMoveEvent(QMouseEvent *mgmnkl);
		void mouseReleaseEvent(QMouseEvent *mgmnkl);
		void focusInEvent(QFocusEvent *mgmnkl);

		bool akdaly;
		QPoint ellqts;
		QPointF kitzjl;

		QWidget *leir;

		QRubberBand* kapod;
		mgzerz * ir;
		QList<rslt*> hzzqjt;

		void hsztzk(bool lecke=1);
		void marka(int lnmtat, bool fnqll);
		void lmzdul(rslt*, bool lecke=1);
		void elktzk(rslt*, bool lecke=1);
		void muri(bool lecke=1);
		void lep(); 

		void gyrtmn();

		jelzpn *kidlgz;

		QVector<rslt*> csals;

		QPointF vmrgem;

		int fhlhjt;

		void amkzrs(int mzgat, int sima);

		kivitl nagy;

		void jlnrdz();

		bool event(QEvent *kelt);

		void munka(bool);

		QAction *fladat;
		QAction *cel;
		QAction *targy;

	public slots:
		void kivalt(const zagv&);
		void detto(QAction*);
		void fajta();
		void alafng(QAction*);
		void dolog();
		void zandek();
		void kltzik(); 
		void megir();
		void alkt();
		void lemasl();
		void kiallt();
		void kitolt();
		void rabir();
		void mozog();

		void kapni();

	signals:
		void jvsltz(const QString &, int);
%>;

class mgzerz : public QRubberBand
<%
	public:
	int kitzjl;
	mgzerz(QRubberBand::Shape, QWidget*);
	void paintEvent(QPaintEvent *);
	void setGeometry(const QRect& tqrost);
%>;

#endif

